"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var common = require('./image-cache-it.common');
var fs = require("file-system");
var utils = require("utils/utils");
var imageSrc = require("image-source");
var style = require("ui/styling/style");
var background = require("ui/styling/background");
var enums_1 = require('ui/enums');
function onStretchPropertyChanged(data) {
    var image = data.object;
    if (!image.android) {
        return;
    }
    switch (data.newValue) {
        case enums_1.Stretch.aspectFit:
            image.android.setScaleType(android.widget.ImageView.ScaleType.FIT_CENTER);
            break;
        case enums_1.Stretch.aspectFill:
            image.android.setScaleType(android.widget.ImageView.ScaleType.CENTER_CROP);
            break;
        case enums_1.Stretch.fill:
            image.android.setScaleType(android.widget.ImageView.ScaleType.FIT_XY);
            break;
        case enums_1.Stretch.none:
        default:
            image.android.setScaleType(android.widget.ImageView.ScaleType.MATRIX);
            break;
    }
}
common.ImageCacheIt.stretchProperty.metadata.onSetNativeValue = onStretchPropertyChanged;
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        _super.call(this);
    }
    Object.defineProperty(ImageCacheIt.prototype, "android", {
        get: function () {
            return this._android;
        },
        enumerable: true,
        configurable: true
    });
    ImageCacheIt.prototype._createUI = function () {
        if (!this.imageUri)
            return;
        this._android = new org.nativescript.widgets.ImageView(this._context);
        if (this.imageUri.toString().substr(0, 2) == '~/') {
            var oldUri = this.imageUri;
            this.imageUri = fs.path.join(fs.knownFolders.currentApp().path, oldUri.replace("~/", ""));
        }
        this._setNativeImage(this.imageUri);
    };
    ImageCacheIt.prototype._setNativeImage = function (nativeImage) {
        if (!this._android)
            return;
        if (nativeImage && nativeImage.indexOf('.gif') > -1) {
            this.glide = com.bumptech.glide.Glide.with(this._context).load(nativeImage).asGif();
            if (this.placeHolder) {
                var ph = this.getImage(this.placeHolder);
                this.glide.placeholder(ph);
            }
            if (this.errorHolder) {
                var eh = this.getImage(this.errorHolder);
                this.glide.error(eh);
            }
            if (this.resize && this.resize !== undefined && this.resize.split(',').length > 1) {
                this.glide.override(parseInt(this.resize.split(',')[0]), parseInt(this.resize.split(',')[1]));
            }
            else if (this.override && this.override !== undefined && this.override.split(',').length > 1) {
                this.glide.override(parseInt(this.override.split(',')[0]), parseInt(this.override.split(',')[1]));
            }
            if (this.centerCrop) {
                this.glide.centerCrop();
            }
            this.glide.into(this._android);
        }
        else {
            if (nativeImage && nativeImage.substr(0, 1) == '/') {
                nativeImage = new java.io.File(nativeImage);
            }
            this.picasso = com.squareup.picasso.Picasso.with(this._context).load(nativeImage);
            if (this.placeHolder) {
                var ph = this.getImage(this.placeHolder);
                this.picasso.placeholder(ph);
            }
            if (this.errorHolder) {
                var eh = this.getImage(this.errorHolder);
                this.picasso.error(eh);
            }
            if (this.resize && this.resize !== undefined && this.resize.split(',').length > 1) {
                this.picasso.resize(parseInt(this.resize.split(',')[0]), parseInt(this.resize.split(',')[1]));
            }
            else if (this.override && this.override !== undefined && this.override.split(',').length > 1) {
                this.picasso.resize(parseInt(this.override.split(',')[0]), parseInt(this.override.split(',')[1]));
            }
            if (this.centerCrop) {
                this.picasso.centerCrop();
            }
            this.picasso.into(this._android);
        }
    };
    ImageCacheIt.prototype.getImage = function (image) {
        switch (typeof image) {
            case 'string':
                if (image && image.indexOf('res://') > -1) {
                    var src = imageSrc.fromResource(image);
                    var res = utils.ad.getApplicationContext().getResources();
                    return new android.graphics.drawable.BitmapDrawable(res, src.android);
                }
                else if (image && image.substr(0, 2) === '~/') {
                    var src = imageSrc.fromFile(image);
                    var res = utils.ad.getApplicationContext().getResources();
                    return new android.graphics.drawable.BitmapDrawable(res, src.android);
                }
        }
    };
    ImageCacheIt.prototype.clear = function () {
        com.squareup.picasso.LruCache.clear();
    };
    return ImageCacheIt;
}(common.ImageCacheIt));
exports.ImageCacheIt = ImageCacheIt;
var ImageStyler = (function () {
    function ImageStyler() {
    }
    ImageStyler.setBorderRadiusProperty = function (v, newValue, defaultValue) {
        if (!v._nativeView) {
            return;
        }
        var val = Math.round(newValue * utils.layout.getDisplayDensity());
        v._nativeView.setCornerRadius(val);
        background.ad.onBackgroundOrBorderPropertyChanged(v);
    };
    ImageStyler.resetBorderRadiusProperty = function (v, nativeValue) {
        if (!v._nativeView) {
            return;
        }
        v._nativeView.setCornerRadius(0);
        background.ad.onBackgroundOrBorderPropertyChanged(v);
    };
    ImageStyler.setBorderWidthProperty = function (v, newValue, defaultValue) {
        if (!v._nativeView) {
            return;
        }
        var val = Math.round(newValue * utils.layout.getDisplayDensity());
        v._nativeView.setBorderWidth(val);
        background.ad.onBackgroundOrBorderPropertyChanged(v);
    };
    ImageStyler.resetBorderWidthProperty = function (v, nativeValue) {
        if (!v._nativeView) {
            return;
        }
        v._nativeView.setBorderWidth(0);
        background.ad.onBackgroundOrBorderPropertyChanged(v);
    };
    ImageStyler.registerHandlers = function () {
        style.registerHandler(style.borderRadiusProperty, new style.StylePropertyChangedHandler(ImageStyler.setBorderRadiusProperty, ImageStyler.resetBorderRadiusProperty), "ImageCacheIt");
        style.registerHandler(style.borderWidthProperty, new style.StylePropertyChangedHandler(ImageStyler.setBorderWidthProperty, ImageStyler.resetBorderWidthProperty), "ImageCacheIt");
    };
    return ImageStyler;
}());
exports.ImageStyler = ImageStyler;
ImageStyler.registerHandlers();
//# sourceMappingURL=image-cache-it.android.js.map